@@ -56,34 +56,37 @@ define('MAC_FILE', __DIR__ . '/files/oui.txt');
  */
 define('BACKEND', __DIR__ . '/backend/');
 /**
- * Library PHPCAS
+ * PHP CAS folder (CAS auth)
  */
-define('PHPCAS', __DIR__ . '/libraries/phpcas/CAS.php');
+define('PHPCAS', __DIR__ . '/vendor/jasig/phpcas/CAS.php');
 /**
- * Library TC-LIB-BARCODE
+ * Autoload composer
  */
-define('TC_LIB_BARCODE', __DIR__ . '/libraries/tclib/Barcode/autoload.php');
+define('COMPOSER_AUTOLOAD', __DIR__ . '/vendor/autoload.php');
 /**
- * Library PASSWORD-COMPAT
+ * Template Mail Directory
  */
-define('PASSWORD_COMPAT', __DIR__ . '/libraries/password_compat/password.php');
+define('TEMPLATE', __DIR__.'/templates/');
 //====================================================================================
 // GUI Options
 //====================================================================================
 /**
  * OCS' MySQL database version
  */
-define('GUI_VER', '7011');
+define('GUI_VER', '7079');
+
+
 /**
  * GUI Version
  */
-define('GUI_VER_SHOW', '2.3.1');
+define('GUI_VER_SHOW', '2.12.3');
 /**
  * Default GUI language
  */
-define('DEFAULT_LANGUAGE', 'english');
+define('DEFAULT_LANGUAGE', 'en_GB');
 define('PAG_INDEX', 'function');
 define('UPDATE_JSON_URI', 'http://check-version.ocsinventory-ng.org');
+define('URL_NEWS', 'http://check-version.ocsinventory-ng.org/newsfeed.json');
 
 //====================================================================================
 // Default OCS DIR
@@ -92,6 +95,10 @@ define('UPDATE_JSON_URI', 'http://check-version.ocsinventory-ng.org');
  * Configuration directory
  */
 define('CONFIG_DIR', __DIR__ . '/config/');
+/**
+ * Profiles directory
+ */
+define('PROFILES_DIR', CONFIG_DIR.'profiles/');
 /**
  * Computer detail configuration directory
  */
@@ -101,6 +108,10 @@ define('CD_CONFIG_DIR', CONFIG_DIR . 'computer/');
  */
 define('PLUGINS_DIR', __DIR__ . '/plugins/');
 define('PLUGINS_GUI_DIR', '/tmp/');
+/**
+ * Language dir
+ */
+define('LANGUAGE_DIR', PLUGINS_DIR . "language/");
 /**
  * HEADER for ocsreports
  */
@@ -112,24 +123,66 @@ define('FOOTER_HTML', __DIR__ . '/require/footer.php');
 /**
  * Main section directory
  */
-define('MAIN_SECTIONS_DIR', "plugins/main_sections/");
+define('MAIN_SECTIONS_DIR', PLUGINS_DIR . "main_sections/");
+define('MAIN_SECTIONS_DIR_VISU', "plugins/main_sections/");
+
+/**
+ * Theme options
+ */
+define('THEMES_DIR', __DIR__ . '/themes/');
+define('DEFAULT_THEME', "OCS");
+
+/**
+ * DEV Options
+ */
 define('DEV_OPTION', false);
 
+//====================================================================================
+// Authentication Configuration
+//====================================================================================
+
+/**
+ * Define the auth type :
+ * - 1 : Local Only
+ * - 2 : Local and LDAP
+ * - 3 : LDAP Only
+ * - 4 : LDAP with SSO
+ * - 5 : Always OK, won't ask for user and password
+ * - 6 : CAS authentication
+ * - 7 : SSO Only (using $_SERVER['REMOTE_USER'] / $_SERVER['HTTP_AUTH_USER'])
+ * 
+ * If LDAP / SSO Basic auth is configured, please configure the LDAP Authentication
+ */
+define('AUTH_TYPE', 1);
+
+/**
+* For LDAP with SSO auth_type, remove the domain of logins like login@domain 
+*
+*/
+
+define('SSO_DEL_DOMAIN',false);
+
+/**
+ * Auth Insecure LDAP, skip SSL Cert (not recommended)
+ * Note : OCS doesn't manage certificate for Ldaps, please edit "/etc/ldap/ldap.conf" to set proper certificate
+ */
+define('AUTH_LDAP_SKIP_CERT', false);
+
+/**
+ * Define password cryptograpgy
+ * To see all available cryptography, read https://www.php.net/manual/fr/function.hash-algos.php
+ */
+define('PASSWORD_CRYPT', 'sha256');
+
 //====================================================================================
 // Plugins Configuration
 //====================================================================================
+
 /**
- * Directory where you put plugin sources
+ * Directory where you put extensions sources
  */
-define('PLUGINS_DL_DIR', __DIR__ . '/download/');
-/**
- * Don't touch this dir used by plugin engine
- */
-define('PLUGINS_SRV_SIDE', __DIR__ . '/upload/');
-/**
- * Plugins engine ws url, don't touch if you don't know what you are doing
- */
-define('PLUGIN_WS_URL', '/ocsplugins');
+define('EXT_DL_DIR', __DIR__ . '/extensions/');
+
 //====================================================================================
 // Misc Options
 //====================================================================================
